@@ -429,7 +429,9 @@
   GL: 				cubocteversion --root			    \\n\
 				droste --root				    \\n\
   GL: 				papercube --root			    \\n\
-  GL: 				skulloop --root				    \\n",
+  GL: 				skulloop --root				    \\n\
+  GL: 				highvoltage --root			    \\n\
+  GL: 				kallisti --root				    \\n",
 "*hacks.antinspect.name:     Ant Inspect",
 "*hacks.antmaze.name:        Ant Maze",
 "*hacks.antspotlight.name:   Ant Spotlight",
@@ -492,6 +494,7 @@
 "*hacks.gravitywell.name:    Gravity Well",
 "*hacks.hexstrut.name:       Hex Strut",
 "*hacks.hextrail.name:       Hex Trail",
+"*hacks.highvoltage.name:    High Voltage",
 "*hacks.ifs.name:            IFS",
 "*hacks.imsmap.name:         IMS Map",
 "*hacks.jigglypuff.name:     Jiggly Puff",
