@@ -22,10 +22,6 @@
 #ifndef __DELAUNAY_H__
 #define __DELAUNAY_H__
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif /* HAVE_CONFIG_H */
-
 typedef struct {
    double x,y,z;
 } XYZ;
