@@ -17,7 +17,6 @@
 # include "xdbe.h"
 #endif /* HAVE_DOUBLE_BUFFER_EXTENSION */
 
-#define countof(x) (sizeof(x)/sizeof(*(x)))
 #define ABS(x) ((x)<0?-(x):(x))
 
 struct state {
@@ -168,7 +167,8 @@ make_throbber (struct state *st, Drawable d, int w, int h, unsigned long pixel)
   t->fuse = 1 + (random() % 4);
   t->thickness = get_integer_resource (st->dpy, "thickness", "Thickness");
 
-  if (st->xgwa.width > 2560) t->thickness *= 3;  /* Retina displays */
+  if (st->xgwa.width > 2560 || st->xgwa.height > 2560)
+    t->thickness *= 3;  /* Retina displays */
 
   if (t->speed < 0) t->speed = -t->speed;
   t->speed += (((random() % t->speed) / 2) - (t->speed / 2));
