@@ -21,9 +21,6 @@
 #define DEF_TEXTURE     "(none)"
 #define DEF_MATHEMATICAL "False"
 
-#undef countof
-#define countof(x) (sizeof((x))/sizeof((*x)))
-
 #undef BELLRAND
 #define BELLRAND(n) ((frand((n)) + frand((n)) + frand((n))) / 3)
 #undef RANDSIGN
@@ -551,15 +548,13 @@ draw_cow (ModeInfo *mi)
 
   glPushMatrix ();
 
-# ifdef HAVE_MOBILE	/* Keep it the same relative size when rotated. */
   {
-    GLfloat h = MI_HEIGHT(mi) / (GLfloat) MI_WIDTH(mi);
-    int o = (int) current_device_rotation();
-    if (o != 0 && o != 180 && o != -180)
-      glScalef (1/h, 1/h, 1/h);
-    glRotatef(o, 0, 0, 1);
+    GLfloat s = (MI_WIDTH(mi) < MI_HEIGHT(mi)
+                 ? (MI_WIDTH(mi) / (GLfloat) MI_HEIGHT(mi))
+                 : 1);
+    glRotatef(current_device_rotation(), 0, 0, 1);
+    glScalef (s, s, s);
   }
-# endif
 
   glScalef (0.5, 0.5, 0.5);
 
