@@ -60,9 +60,6 @@ enum {
 
 #define MARBLE_TEXTURE_SIZE 256
 
-#undef countof
-#define countof(x) (sizeof((x))/sizeof((*x)))
-
 #include <math.h>
 #include "xlockmore.h"
 
@@ -1978,14 +1975,12 @@ ENTRYPOINT void draw_glhanoi(ModeInfo * mi)
 	update_glhanoi(glhanoi);
 	updateView(glhanoi);
 
-# ifdef HAVE_MOBILE	/* Keep it the same relative size when rotated. */
     {
-      GLfloat h = MI_HEIGHT(mi) / (GLfloat) MI_WIDTH(mi);
-      int o = (int) current_device_rotation();
-      if (o != 0 && o != 180 && o != -180)
-        glScalef (1/h, 1/h, 1/h);
+      GLfloat s = (MI_WIDTH(mi) < MI_HEIGHT(mi)
+                   ? (MI_WIDTH(mi) / (GLfloat) MI_HEIGHT(mi))
+                   : 1);
+      glScalef (s, s, s);
     }
-# endif
 
 	if(!glhanoi->wire && glhanoi->texture) {
 		glEnable(GL_TEXTURE_2D);
