@@ -10,29 +10,12 @@
  * implied warranty.
  */
 
+#include "screenhackI.h"
+
 #include <math.h>
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef HAVE_CONFIG_H
-# include "config.h"
-#endif
-
-#ifdef HAVE_COCOA
-# include "jwxyz.h"
-#elif defined(HAVE_ANDROID)
-# include "jwxyz.h"
-# include <GLES/gl.h>
-#else  /* real X11 */
-# include <X11/X.h>
-# include <X11/Xlib.h>
-# include <GL/gl.h>
-#endif /* !HAVE_COCOA */
-
-#ifdef HAVE_JWZGLES
-# include "jwzgles.h"
-#endif /* HAVE_JWZGLES */
-
 # define Button4 4  /* WTF */
 # define Button5 5
 # define Button6 6
@@ -327,7 +310,7 @@ gltrackball_event_handler (XEvent *event,
             event->xbutton.button == Button6 ||
             event->xbutton.button == Button7))
     {
-      gltrackball_mousewheel (ts, event->xbutton.button, 10,
+      gltrackball_mousewheel (ts, event->xbutton.button, 1,
                               !!event->xbutton.state);
       return True;
     }
