@@ -58,7 +58,6 @@ static const char sccsid[] = "@(#)morph3d.c	5.01 2001/03/01 xlockmore";
 						"*count: 		0		\n"		\
 						"*suppressRotationAnimation: True\n" \
 
-# define free_morph3d 0
 # define release_morph3d 0
 # define morph3d_handle_event xlockmore_no_events
 # include "xlockmore.h"		/* from the xscreensaver distribution */
@@ -760,7 +759,7 @@ draw_morph3d(ModeInfo * mi)
 		return;
 
     mi->polygon_count = 0;
-	glXMakeCurrent(display, window, *(mp->glx_context));
+	glXMakeCurrent(display, window, *mp->glx_context);
 
 	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
@@ -775,14 +774,12 @@ draw_morph3d(ModeInfo * mi)
 		glScalef(Scale4Iconic * mp->WindH / mp->WindW, Scale4Iconic, Scale4Iconic);
 	}
 
-# ifdef HAVE_MOBILE	/* Keep it the same relative size when rotated. */
     {
-      GLfloat h = MI_HEIGHT(mi) / (GLfloat) MI_WIDTH(mi);
-      int o = (int) current_device_rotation();
-      if (o != 0 && o != 180 && o != -180)
-        glScalef (1/h, h, 1);
+      GLfloat s = (MI_WIDTH(mi) < MI_HEIGHT(mi)
+                   ? (MI_WIDTH(mi) / (GLfloat) MI_HEIGHT(mi))
+                   : 1);
+      glScalef (s, s, s);
     }
-# endif
 
 	glRotatef(mp->step * 100, 1, 0, 0);
 	glRotatef(mp->step * 95, 0, 1, 0);
@@ -832,6 +829,12 @@ change_morph3d(ModeInfo * mi)
 }
 #endif /* !STANDALONE */
 
+ENTRYPOINT void
+free_morph3d(ModeInfo * mi)
+{
+  /* nothing to do */
+}
+
 #endif
 
 XSCREENSAVER_MODULE ("Morph3D", morph3d)
