@@ -34,9 +34,8 @@ static const char sccsid[] = "@(#)tunnel_draw.c	5.13 2004/05/25 xlockmore";
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "screenhackI.h"
+#include "tunnel_draw.h"
 
 #ifdef USE_GL /* whole file */
 
@@ -44,23 +43,6 @@ static const char sccsid[] = "@(#)tunnel_draw.c	5.13 2004/05/25 xlockmore";
 #include <stdlib.h>
 #include <math.h>
 
-#ifdef STANDALONE
-# ifdef HAVE_COCOA
-#  include <OpenGL/gl.h>
-#  include <OpenGL/glu.h>
-# else
-#  include <GL/gl.h>
-#  include <GL/glu.h>
-# endif
-#endif
-
-#include "tunnel_draw.h"
-
-#ifdef STANDALONE /* For NRAND() */
-#include "xlockmoreI.h"          /* in xscreensaver distribution */
-#else /* STANDALONE */
-#include "xlock.h"              /* in xlockmore distribution */
-#endif /* STANDALONE */
 
 typedef struct 
 {
@@ -114,7 +96,8 @@ struct tunnel_state {
 };
 
 /*=================== Vector normalization ==================================*/
-static void normalize(cvPoint *V)
+static void
+normalize(cvPoint *V)
 {
   float d;
 
@@ -128,7 +111,8 @@ static void normalize(cvPoint *V)
 }
 /*=================== C = A x B  (Vector multiply) ==========================*/
 #if 0
-static void vect_mult(cvPoint *A, cvPoint *B, cvPoint *C)
+static void
+vect_mult(cvPoint *A, cvPoint *B, cvPoint *C)
 {
 	/* Vector multiply */
 	C->x = A->y*B->z - A->z*B->y;
@@ -138,7 +122,8 @@ static void vect_mult(cvPoint *A, cvPoint *B, cvPoint *C)
 #endif
 
 /* Catmull-Rom Curve calculations */
-static void cvCatmullRom(cvPoint *p, float t, cvPoint *outp)
+static void
+cvCatmullRom(cvPoint *p, float t, cvPoint *outp)
 {
 	float t2, t3, t1;
 
@@ -159,7 +144,8 @@ static void cvCatmullRom(cvPoint *p, float t, cvPoint *outp)
 // outp - output point
 //==========================================================================
 */
-static void RotateAroundLine(cvPoint *p, cvPoint *pp, cvPoint *pl, float a, cvPoint *outp)
+static void
+RotateAroundLine(cvPoint *p, cvPoint *pp, cvPoint *pl, float a, cvPoint *outp)
 {
 	cvPoint p1, p2;
 	float l, m, n, ca, sa;
@@ -186,7 +172,8 @@ static void RotateAroundLine(cvPoint *p, cvPoint *pp, cvPoint *pl, float a, cvPo
 
 
 /*=================== Load camera and tunnel path ==========================*/
-static void LoadPath(struct tunnel_state *st)
+static void
+LoadPath(struct tunnel_state *st)
 {
 	float x, y, z;
 	tnPath *path1=NULL, *path2=NULL;
@@ -225,7 +212,7 @@ static void LoadPath(struct tunnel_state *st)
 
 /*=================== Tunnel Initialization ================================*/
 struct tunnel_state *
-InitTunnel(void)
+atunnel_InitTunnel(void)
 {
     struct tunnel_state *st = (struct tunnel_state *) calloc (1, sizeof(*st));
 	LoadPath(st);
@@ -233,11 +220,12 @@ InitTunnel(void)
     return st;
 }
 
-void DrawTunnel(struct tunnel_state *st, 
+void
+atunnel_DrawTunnel(struct tunnel_state *st, 
                 int do_texture, int do_light, GLuint *textures)
 {
 	tnPath *p, *p1, *cmpos;
-	cvPoint op, p4[4], T, ppp, ppp1, op1, op2;
+	cvPoint op, p4[4], T, ppp, op1, op2;
 	float t;
 	int i, j, k, flag;
 	cvPoint points[10];
@@ -345,6 +333,7 @@ void DrawTunnel(struct tunnel_state *st,
 			/*  End of tunnel */
 			st->ModeX = 1.0;
 			st->ModeXFlag = 0;
+            glEnd();
 			return;
 		}
 		cvCatmullRom(p4, t, &op);
@@ -377,15 +366,12 @@ void DrawTunnel(struct tunnel_state *st,
 			/*  End of tunnel */
 			st->ModeX = 1.0;
 			st->ModeXFlag = 0;
+            glEnd();
 			return;
 		}
 			
 		cvCatmullRom(p4, t, &op1);
 
-		ppp1.x = op1.x;
-		ppp1.y = op1.y;
-		ppp1.z = op1.z + 0.25;
-
 		T.x = op1.x - op.x;
 		T.y = op1.y - op.y;
 		T.z = op1.z - op.z;
@@ -439,7 +425,8 @@ void DrawTunnel(struct tunnel_state *st,
 }
 
 /* =================== Show splash screen =================================== */
-void SplashScreen(struct tunnel_state *st, 
+void
+atunnel_SplashScreen(struct tunnel_state *st, 
                   int do_wire, int do_texture, int do_light)
 {
 	if (st->ModeX > 0)
@@ -497,7 +484,8 @@ void SplashScreen(struct tunnel_state *st,
 	}
 }
 
-void FreeTunnel(struct tunnel_state *st)
+void
+atunnel_FreeTunnel(struct tunnel_state *st)
 {
   free (st);
 }
