@@ -68,6 +68,7 @@ static const char sccsid[] = "@(#)pacman.c	5.00 2000/11/01 xlockmore";
 #include "pacman.h"
 #include "pacman_ai.h"
 #include "pacman_level.h"
+#include "ximage-loader.h"
 #include "images/gen/pacman_png.h"
 
 #ifdef DISABLE_INTERACTIVE
@@ -315,7 +316,7 @@ draw_position (ModeInfo * mi, int x, int y, int color)
     Window window = MI_WINDOW (mi);
     pacmangamestruct *pp = &pacman_games[MI_SCREEN (mi)];
     XFontStruct *font = NULL;
-    char *f_name = "-*-utopia-*-r-*-*-*-600-*-*-p-*-*-*";
+    char *f_name = "Utopia 60, Helvetica 60";
     char *s = NULL;
 
     font = load_font_retry (display, f_name);
@@ -338,7 +339,7 @@ draw_number (ModeInfo * mi, int x, int y, int num, int color)
     Window window = MI_WINDOW (mi);
     pacmangamestruct *pp = &pacman_games[MI_SCREEN (mi)];
     XFontStruct *font = NULL;
-    char *f_name = "-*-utopia-*-r-*-*-*-600-*-*-p-*-*-*";
+    char *f_name = "Utopia 60, Helvetica 60";
     char *s = NULL;
 
     font = load_font_retry (display, f_name);
@@ -390,7 +391,7 @@ draw_string (ModeInfo * mi, int x, int y, char *s, int color)
     Window window = MI_WINDOW (mi);
     pacmangamestruct *pp = &pacman_games[MI_SCREEN (mi)];
     XFontStruct *font = NULL;
-    char *f_name = "-*-utopia-*-r-*-*-*-600-*-*-p-*-*-*";
+    char *f_name = "Utopia 60, Helvetica 60";
 
     font = load_font_retry (display, f_name);
     assert (font != NULL);
@@ -1139,7 +1140,7 @@ load_pixmaps (Display ** dpy, Window window, pacmangamestruct ** ps)
     pacmangamestruct *pp = *ps;
     Display *display = *dpy;
     Pixmap sprites, sprites_mask;
-    int i, j, k, m, sw, sh, srcy;
+    int i, j, k, /* m, */ sw, sh, srcy;
 /*    int w = pp->spritexs;
     int h = pp->spriteys;*/
     GC gc = 0;
@@ -1164,7 +1165,7 @@ load_pixmaps (Display ** dpy, Window window, pacmangamestruct ** ps)
                                   pp->spritexs, pp->spriteys);
 
     for (i = 0; i < 4; i++) {
-        m = 0;
+        /* m = 0; */
         for (j = 0; j < MAXGDIR; j++) {
             for (k = 0; k < MAXGWAG; k++) {
                 pp->ghostPixmap[i][j][k] =
@@ -1174,7 +1175,7 @@ load_pixmaps (Display ** dpy, Window window, pacmangamestruct ** ps)
                     scale_pixmap (&display, pp->stippledGC,
                                   pp->ghostPixmap[i][j][k], pp->spritexs,
                                   pp->spriteys);
-                m++;
+                /* m++; */
                 srcy += sw;
                 if (srcy >= sh) abort();
             }
@@ -1182,13 +1183,13 @@ load_pixmaps (Display ** dpy, Window window, pacmangamestruct ** ps)
     }
 
     /* load the scared ghost */
-    m = 0;
+    /* m = 0; */
     for (i = 0; i < MAXGFLASH; i++) {
         for (j = 0; j < MAXGWAG; j++) {
             pp->s_ghostPixmap[i][j] =
                 subpixmap (display, window, sprites, sw, sw, srcy,
                            xgwa.depth);
-            m++;
+            /* m++; */
             pp->s_ghostPixmap[i][j] = scale_pixmap (&display, pp->stippledGC,
                                                     pp->s_ghostPixmap[i][j],
                                                     pp->spritexs,
@@ -1213,7 +1214,7 @@ load_pixmaps (Display ** dpy, Window window, pacmangamestruct ** ps)
 
     /* Load the pacman pixmaps and their mask. */
 
-    m = 0;
+    /* m = 0; */
     for (i = 0; i < 4; i++) {
         for (j = 0; j < MAXMOUTH; j++) {
             pp->pacmanPixmap[i][j] =
@@ -1221,7 +1222,7 @@ load_pixmaps (Display ** dpy, Window window, pacmangamestruct ** ps)
                            xgwa.depth);
             pp->pacmanMask[i][j] =
                 subpixmap (display, window, sprites_mask, sw, sw, srcy, 1);
-            m++;
+            /* m++; */
             pp->pacmanPixmap[i][j] = scale_pixmap (&display, pp->stippledGC,
                                                    pp->pacmanPixmap[i][j],
                                                    pp->spritexs,
